@@ -26,6 +26,7 @@ import io
 from copy import deepcopy
 from itertools import chain
 from ruamel.yaml import YAML as yaml
+import toml
 
 # local imports
 from dotdrop.version import __version__ as VERSION
@@ -96,19 +97,23 @@ class CfgYaml:
     lnk_nolink = LinkTypes.NOLINK.name.lower()
     lnk_link = LinkTypes.LINK.name.lower()
     lnk_children = LinkTypes.LINK_CHILDREN.name.lower()
+    lnk_absolute = LinkTypes.ABSOLUTE.name.lower()
+    lnk_relative = LinkTypes.RELATIVE.name.lower()
 
     # checks
-    allowed_link_val = [lnk_nolink, lnk_link, lnk_children]
+    allowed_link_val = [lnk_nolink, lnk_link, lnk_children,
+                        lnk_absolute, lnk_relative]
     top_entries = [key_dotfiles, key_settings, key_profiles]
 
     def __init__(self, path, profile=None, addprofiles=None,
-                 reloading=False, debug=False):
+                 reloading=False, debug=False, imported_configs=None):
         """
         config parser
         @path: config file path
         @profile: the selected profile names
         @addprofiles: included profiles names (list)
         @reloading: true when reloading
+        @imported_configs: paths of config files that have been imported so far
         @debug: debug flag
         """
         self._path = os.path.abspath(path)
@@ -116,6 +121,8 @@ class CfgYaml:
         self._reloading = reloading
         self._debug = debug
         self._log = Logger(debug=self._debug)
+        # config format
+        self._config_format = 'yaml'
         # config needs to be written
         self._dirty = False
         # indicates the config has been updated
@@ -124,6 +131,8 @@ class CfgYaml:
         self._profilevarskeys = []
         # included profiles
         self._inc_profiles = addprofiles or []
+        # imported configs
+        self.imported_configs = imported_configs or []
 
         # init the dictionaries
         self.settings = {}
@@ -216,6 +225,13 @@ class CfgYaml:
             title = 'variables defined (after template include)'
             self._debug_dict(title, self.variables)
 
+        ##################################################
+        # template config entries
+        ##################################################
+        entry = self.settings[self.key_settings_dotpath]
+        val = self._template_item(entry)
+        self.settings[self.key_settings_dotpath] = val
+
         ##################################################
         # parse the other blocks
         ##################################################
@@ -284,8 +300,9 @@ class CfgYaml:
         newlink = self._template_item(link)
         # check link value
         if newlink not in self.allowed_link_val:
-            err = 'bad value: {}'.format(newlink)
+            err = 'bad link value: {}'.format(newlink)
             self._log.err(err)
+            self._log.err('allowed: {}'.format(self.allowed_link_val))
             raise YamlException('config content error: {}'.format(err))
         return newlink
 
@@ -320,16 +337,29 @@ class CfgYaml:
         return newdst
 
     def add_dotfile_to_profile(self, dotfile_key, profile_key):
-        """add an existing dotfile key to a profile_key"""
+        """
+        add an existing dotfile key to a profile_key
+        we test using profiles variable since it merges
+        imported ones (include, etc) but insert in main
+        yaml only
+        """
+        # create the profile if it doesn't exist
         self._new_profile(profile_key)
-        profile = self._yaml_dict[self.key_profiles][profile_key]
+        profile = self.profiles[profile_key]
+
+        # ensure profile dotfiles list is not None
         if self.key_profile_dotfiles not in profile or \
                 profile[self.key_profile_dotfiles] is None:
             profile[self.key_profile_dotfiles] = []
+            self._yaml_dict[self.key_profiles][profile_key] = []
+
+        # add to the profile
         pdfs = profile[self.key_profile_dotfiles]
         if self.key_all not in pdfs and \
                 dotfile_key not in pdfs:
-            profile[self.key_profile_dotfiles].append(dotfile_key)
+            # append dotfile
+            pro = self._yaml_dict[self.key_profiles][profile_key]
+            pro[self.key_profile_dotfiles].append(dotfile_key)
             if self._debug:
                 msg = 'add \"{}\" to profile \"{}\"'.format(dotfile_key,
                                                             profile_key)
@@ -451,7 +481,7 @@ class CfgYaml:
             self._dbg('saving to {}'.format(self._path))
         try:
             with open(self._path, 'w', encoding='utf8') as file:
-                self._yaml_dump(content, file)
+                self._yaml_dump(content, file, fmt=self._config_format)
         except Exception as exc:
             self._log.err(exc)
             err = 'error saving config: {}'.format(self._path)
@@ -469,7 +499,7 @@ class CfgYaml:
         """dump the config dictionary"""
         output = io.StringIO()
         content = self._prepare_to_save(self._yaml_dict.copy())
-        self._yaml_dump(content, output)
+        self._yaml_dump(content, output, fmt=self._config_format)
         return output.getvalue()
 
     ########################################################
@@ -981,7 +1011,8 @@ class CfgYaml:
             self._dbg('included profiles: {}'.format(self._inc_profiles))
         sub = CfgYaml(path, profile=self._profile,
                       addprofiles=self._inc_profiles,
-                      debug=self._debug)
+                      debug=self._debug,
+                      imported_configs=self.imported_configs)
 
         # settings are ignored from external file
         # except for filter_file and func_file
@@ -1003,6 +1034,9 @@ class CfgYaml:
         self.trans_w = self._merge_dict(self.trans_w, sub.trans_w)
         self._clear_profile_vars(sub.variables)
 
+        self.imported_configs.append(path)
+        self.imported_configs += sub.imported_configs
+
         if self._debug:
             self._debug_dict('add import_configs var', sub.variables)
         self._add_variables(sub.variables, prio=True)
@@ -1015,6 +1049,10 @@ class CfgYaml:
             return
         paths = self._resolve_paths(imp)
         for path in paths:
+            if path in self.imported_configs:
+                err = '{} imported more than once in {}'.format(path,
+                                                                self._path)
+                raise YamlException(err)
             self._import_config(path)
 
     def _import_sub(self, path, key, mandatory=False, patch_func=None):
@@ -1049,6 +1087,9 @@ class CfgYaml:
             self._yaml_dict[self.key_profiles][key] = {
                 self.key_profile_dotfiles: []
             }
+            self.profiles[key] = {
+                self.key_profile_dotfiles: []
+            }
             if self._debug:
                 self._dbg('adding new profile: {}'.format(key))
             self._dirty = True
@@ -1102,9 +1143,23 @@ class CfgYaml:
                 dotfile[self.key_dotfile_link] = new
                 self._dirty = True
                 self._dirty_deprecated = True
-                self._log.warn('deprecated \"link\" value')
+                warn = 'deprecated \"link: <boolean>\"'
+                warn += ', updated to \"link: {}\"'.format(new)
+                self._log.warn(warn)
 
-            elif old_key in dotfile and \
+            if self.key_dotfile_link in dotfile and \
+                    dotfile[self.key_dotfile_link] == self.lnk_link:
+                # patch "link: link"
+                # to "link: absolute"
+                new = self.lnk_absolute
+                dotfile[self.key_dotfile_link] = new
+                self._dirty = True
+                self._dirty_deprecated = True
+                warn = 'deprecated \"link: link\"'
+                warn += ', updated to \"link: {}\"'.format(new)
+                self._log.warn(warn)
+
+            if old_key in dotfile and \
                     isinstance(dotfile[old_key], bool):
                 # patch link_children: <bool>
                 cur = dotfile[old_key]
@@ -1115,7 +1170,9 @@ class CfgYaml:
                 dotfile[self.key_dotfile_link] = new
                 self._dirty = True
                 self._dirty_deprecated = True
-                self._log.warn('deprecated \"link_children\" value')
+                warn = 'deprecated \"link_children\" value'
+                warn += ', updated to \"{}\"'.format(new)
+                self._log.warn(warn)
 
     ########################################################
     # yaml utils
@@ -1145,12 +1202,14 @@ class CfgYaml:
             self._dbg(cfg.rstrip())
             self._dbg('----------end:{}----------'.format(path))
         try:
-            content = self._yaml_load(path)
+            content, fmt = self._yaml_load(path)
+            self._config_format = fmt
         except Exception as exc:
             self._log.err(exc)
             err = 'config yaml error: {}'.format(path)
             raise YamlException(err) from exc
-
+        if self._debug:
+            self._dbg('format: {}'.format(self._config_format))
         return content
 
     def _validate(self, yamldict):
@@ -1172,17 +1231,28 @@ class CfgYaml:
         if not yamldict[self.key_settings]:
             # configs empty
             return
+
+        # check settings values
         settings = yamldict[self.key_settings]
         if self.key_settings_link_dotfile_default not in settings:
             return
         val = settings[self.key_settings_link_dotfile_default]
         if val not in self.allowed_link_val:
-            err = 'bad value: {}'.format(val)
+            err = 'bad link value: {}'.format(val)
             self._log.err(err)
+            self._log.err('allowed: {}'.format(self.allowed_link_val))
             raise YamlException('config content error: {}'.format(err))
 
     @classmethod
     def _yaml_load(cls, path):
+        """load config file"""
+        is_toml = path.lower().endswith(".toml")
+        if is_toml:
+            return cls.__toml_load(path), 'toml'
+        return cls.__yaml_load(path), 'yaml'
+
+    @classmethod
+    def __yaml_load(cls, path):
         """load from yaml"""
         with open(path, 'r', encoding='utf8') as file:
             data = yaml()
@@ -1191,13 +1261,41 @@ class CfgYaml:
         return content
 
     @classmethod
-    def _yaml_dump(cls, content, where):
+    def __toml_load(cls, path):
+        """load from toml"""
+        with open(path, 'r', encoding='utf8') as file:
+            data = file.read()
+        content = toml.loads(data)
+        # handle inexistent dotfiles/profiles
+        # since toml doesn't have a nul/nil/null/none
+        if cls.key_dotfiles not in content:
+            content[cls.key_dotfiles] = None
+        if cls.key_profiles not in content:
+            content[cls.key_profiles] = None
+        return content
+
+    @classmethod
+    def _yaml_dump(cls, content, file, fmt='yaml'):
+        """dump config file"""
+        if fmt == 'toml':
+            return cls.__toml_dump(content, file)
+        if fmt == 'yaml':
+            return cls.__yaml_dump(content, file)
+        raise YamlException("unsupported format")
+
+    @classmethod
+    def __yaml_dump(cls, content, file):
         """dump to yaml"""
         data = yaml()
         data.default_flow_style = False
         data.indent = 2
         data.typ = 'rt'
-        data.dump(content, where)
+        data.dump(content, file)
+
+    @classmethod
+    def __toml_dump(cls, content, file):
+        """dump to toml"""
+        toml.dump(content, file)
 
     ########################################################
     # templating
@@ -1205,8 +1303,12 @@ class CfgYaml:
 
     def _redefine_templater(self):
         """create templater based on current variables"""
-        fufile = self.settings[Settings.key_func_file]
-        fifile = self.settings[Settings.key_filter_file]
+        fufile = None
+        fifile = None
+        if Settings.key_func_file in self.settings:
+            fufile = self.settings[Settings.key_func_file]
+        if Settings.key_filter_file in self.settings:
+            fifile = self.settings[Settings.key_filter_file]
         self._tmpl = Templategen(variables=self.variables,
                                  func_file=fufile,
                                  filter_file=fifile)
@@ -1633,7 +1735,7 @@ class CfgYaml:
             if self._debug:
                 self._dbg('saving uservariables values to {}'.format(path))
             with open(path, 'w', encoding='utf8') as file:
-                self._yaml_dump(content, file)
+                self._yaml_dump(content, file, fmt=self._config_format)
         except Exception as exc:
             # self._log.err(exc)
             err = 'error saving uservariables to {}'.format(path)
