@@ -158,7 +158,7 @@ def _dotfile_compare(opts, dotfile, tmp):
 
     # compare
     # need to be executed before cleaning
-    diff = comp.compare(src, dotfile.dst, ignore=ignores)
+    diff = comp.compare(src, dotfile.dst, ignore=ignores, mode=dotfile.chmod)
 
     # clean tmp transformed dotfile if any
     if tmpsrc:
@@ -220,8 +220,11 @@ def _dotfile_install(opts, dotfile, tmpdir=None):
         dotfile.src,
         ignore=ignores,
     )
-    if hasattr(dotfile, 'link') and dotfile.link == LinkTypes.LINK:
-        # link
+    if hasattr(dotfile, 'link') and dotfile.link in (
+        LinkTypes.LINK, LinkTypes.LINK_CHILDREN,
+        LinkTypes.RELATIVE, LinkTypes.ABSOLUTE
+    ):
+        # nolink|relative|absolute|link_children
         ret, err = inst.install(templ, dotfile.src, dotfile.dst,
                                 dotfile.link,
                                 actionexec=pre_actions_exec,
@@ -229,16 +232,6 @@ def _dotfile_install(opts, dotfile, tmpdir=None):
                                 ignore=ignores,
                                 chmod=dotfile.chmod,
                                 force_chmod=opts.install_force_chmod)
-    elif hasattr(dotfile, 'link') and \
-            dotfile.link == LinkTypes.LINK_CHILDREN:
-        # link_children
-        ret, err = inst.install(templ, dotfile.src, dotfile.dst,
-                                dotfile.link,
-                                actionexec=pre_actions_exec,
-                                is_template=is_template,
-                                chmod=dotfile.chmod,
-                                ignore=ignores,
-                                force_chmod=opts.install_force_chmod)
     else:
         # nolink
         src = dotfile.src
@@ -652,7 +645,7 @@ def cmd_remove(opts):
             k = dotfile.key
             # ignore if uses any type of link
             if dotfile.link != LinkTypes.NOLINK:
-                msg = '{} uses link/link_children, remove manually'
+                msg = '{} uses symlink, remove manually'
                 LOG.warn(msg.format(k))
                 continue
 
